sampler textureSampler : register(s0);

float2 LightPos;
float2 ScreenDims;
float Radius;

static const float minBlur = 0.0f;
static const float maxBlur = 5.0f;
static const int KernelSize = 13;
static const float2 OffsetAndWeight[KernelSize] =
{
    { -6, 0.002216 },
    { -5, 0.008764 },
    { -4, 0.026995 },
    { -3, 0.064759 },
    { -2, 0.120985 },
    { -1, 0.176033 },
    {  0, 0.199471 },
    {  1, 0.176033 },
    {  2, 0.120985 },
    {  3, 0.064759 },
    {  4, 0.026995 },
    {  5, 0.008764 },
    {  6, 0.002216 },
};

float4 PixelShaderFunction(float2 texcoord : TEXCOORD0) : COLOR0
{
	float sum = 0;
	float2 screenPos = float2(texcoord.x * ScreenDims.x, texcoord.y * ScreenDims.y);
	float dist = length(screenPos - LightPos);
	  
    for (int i = 0; i < KernelSize; i++)
	{    
      sum += tex2D( textureSampler, texcoord + OffsetAndWeight[i].x * lerp(minBlur, maxBlur , saturate(dist/ Radius))/ ScreenDims.x * float2(1,0) ).r * OffsetAndWeight[i].y;
    }
	  
	float4 result = sum;
	result.a = 1;
    return result;
}

technique Technique1
{
    pass Pass1
    {

        PixelShader = compile ps_2_0 PixelShaderFunction();
    }
}
