#define PI 3.14159265

sampler occlusionSampler : register(s0);

float2 ScreenDimensions;
float DiagonalLength;
float2 LightPos;
float LightPow;
float Radius;
float Bias;

float4 PixelShaderFunction(float2 Texcoord : TEXCOORD0) : COLOR0
{
	float2 screenCoords = float2(ScreenDimensions.x * Texcoord.x, ScreenDimensions.y * Texcoord.y);
	float2 lightToPix = screenCoords - LightPos;
	float pixDist = length(lightToPix);
	float occlusionU = acos(dot(float2(0, 1), normalize(lightToPix)));
	occlusionU /= PI;
	float4 occlusionDist = tex2D(occlusionSampler, float2(occlusionU, 0.5));
	occlusionDist.xyz = mul(occlusionDist.xyz, DiagonalLength);
	float dist = (screenCoords.x > LightPos.x) ? occlusionDist.r : occlusionDist.g;
	float3 lighting = (1 - (pixDist / Radius)) * LightPow;
	if (pixDist - Bias < min(Radius, dist))
		return float4(lighting, 1);
	return float4(0, 0, 0, 1);
}

technique Technique1
{
    pass Pass1
    {
        PixelShader = compile ps_2_0 PixelShaderFunction();
    }
}
