#define PI 3.14159265

float2 LightPos;
float TargetWidth;
float TargetHeight;
float DiagonalLength;

sampler shadowCastersSampler : register(s0);

float4 PixelShaderFunction(float2 texCoord : TEXCOORD0) : COLOR0
{
	float sinTheta, cosTheta;
	sincos((texCoord.x * PI), sinTheta, cosTheta);

	float2 norm1 = float2(sinTheta, cosTheta);
	float2 norm2 = float2(-sinTheta, cosTheta);

	float2 LightDist;

	if (cosTheta == 0)
	{
		LightDist = float2(TargetWidth - LightPos.x, LightPos.x);
	}
	else if (sinTheta == 0)
	{
		LightDist = abs((((cosTheta + 1) / 2.0) * TargetHeight) - LightPos.y);
	}
	else
	{
		float4 hit = float4 (LightPos.x / sinTheta, (TargetWidth - LightPos.x) / sinTheta, (TargetHeight - LightPos.y) / cosTheta, -LightPos.y / cosTheta);
		hit = (hit < 0) ? 2 * TargetWidth : hit;
		float yHit = min(hit.z, hit.w);

		LightDist = min(hit.yx, yHit);
	}
	LightDist = mul(LightDist, texCoord.y);
	norm1 = mul(norm1, LightDist.x);
	norm2 = mul(norm2, LightDist.y);
	float4 sample1 = tex2D(shadowCastersSampler, float2((LightPos.x + norm1.x) / TargetWidth, (LightPos.y + norm1.y) / TargetHeight));
	float4 sample2 = tex2D(shadowCastersSampler, float2((LightPos.x + norm2.x) / TargetWidth, (LightPos.y + norm2.y) / TargetHeight));

	return float4((sample1.a < 0.01) ? 1 : LightDist.x / DiagonalLength, (sample2.a < 0.01) ? 1 : LightDist.y / DiagonalLength, 0, 1);
}

technique Technique1
{
    pass Pass1
    {
        PixelShader = compile ps_2_0 PixelShaderFunction();
    }
}
