#define PI 3.14159265

float2 LightPos;
float MinAngle;
float MaxAngle;
float ArcSize;
float TargetWidth;
float TargetHeight;
float DiagonalLength;

sampler shadowCastersSampler : register(s0);

float4 PixelShaderFunction(float2 texCoord : TEXCOORD0) : COLOR0
{
	float sinTheta, cosTheta;
	sincos(MinAngle + (texCoord.x * ArcSize), sinTheta, cosTheta);

	float2 norm = float2(-sinTheta, cosTheta);

	float LightDist;

	if (cosTheta == 0)
	{
		LightDist = abs((((1 - sinTheta) / 2.0) * TargetWidth) - LightPos.x);
	}
	else if (sinTheta == 0)
	{
		LightDist = abs((((cosTheta + 1) / 2.0) * TargetHeight) - LightPos.y);
	}
	else
	{
		float4 hit = float4 (LightPos.x / sinTheta, (LightPos.x - TargetWidth) / sinTheta, (TargetHeight - LightPos.y) / cosTheta, -LightPos.y / cosTheta);
		hit = (hit < 0) ? 2 * TargetWidth : hit;
		float yHit = min(hit.z, hit.w);

		LightDist = min(min(hit.x, hit.y), min(hit.w, hit.z));
	}
	LightDist = LightDist * texCoord.y;
	norm = norm * LightDist;
	float4 col = tex2D(shadowCastersSampler, float2((LightPos.x + norm.x) / TargetWidth, (LightPos.y + norm.y) / TargetHeight));

	return float4((col.a < 0.01) ? 1 : LightDist / DiagonalLength, 0, 0, 1);
}

technique Technique1
{
    pass Pass1
    {
        // TODO: set renderstates here.
        PixelShader = compile ps_2_0 PixelShaderFunction();
    }
}
